def func():
    import datetime

    print(datetime.timezone(-1))


def func():
    from datetime import timezone

    print(timezone.utc)


def func():
    from datetime import timezone as tz

    print(tz.utc)


def func():
    import datetime

    print(datetime.timezone.utc)


def func():
    import datetime as dt

    print(dt.timezone.utc)


def func():
    import datetime

    print((
        datetime
        .timezone  # text
        .utc
    ))

